==> v0.68.zip: welco/welco/sources/mail/management/commands/feed_mail.py <==
# welco - multichannel request processing
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from optparse import make_option
import os

from django.core.files import File
from django.core.management.base import BaseCommand, CommandError

from ...models import Mail

class Command(BaseCommand):
    args = ['category', '...']

    option_list = BaseCommand.option_list + (
            make_option('--category',
                        dest='category',
                        default=None),
            )

    def handle(self, *args, **kwargs):
        count = 0
        for filepath in args:
            if not os.path.exists(filepath):
                continue
            if not open(filepath).read(5) == '%PDF-':
                continue
            mail = Mail(content=File(open(filepath)))
            mail.scanner_category = kwargs.get('category')
            mail.save()
            count += 1
        if count == 0:
            raise CommandError('nothing got imported')

==> v0.82.zip: welco/welco/sources/mail/management/commands/feed_mail.py <==
# welco - multichannel request processing
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
from optparse import make_option

from django.core.files import File
from django.core.management.base import BaseCommand, CommandError

from ...models import Mail


class Command(BaseCommand):
    def add_arguments(self, parser):
        parser.add_argument('--category', metavar='CATEGORY', default=None)
        parser.add_argument('filenames', metavar='FILENAME', nargs='+')

    def handle(self, filenames, *args, **kwargs):
        count = 0
        for filepath in filenames:
            if not os.path.exists(filepath):
                continue
            if not open(filepath).read(5) == '%PDF-':
                continue
            mail = Mail(content=File(open(filepath)))
            mail.scanner_category = kwargs.get('category')
            mail.save()
            count += 1
        if count == 0:
            raise CommandError('nothing got imported')
